# Generated by Django 5.1.1 on 2024-12-22 21:16

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0025_employee_accommodations"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="employee",
            name="accommodations",
        ),
    ]
