# Generated by Django 5.1.1 on 2024-12-10 16:33

import bloomerp.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0053_remove_documenttemplate_standard_document_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="documenttemplatefreevariable",
            name="help_text",
            field=models.CharField(
                blank=True,
                help_text="Help text for the variable that will be shown upon creation.",
                max_length=100,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="documenttemplatefreevariable",
            name="name",
            field=models.CharField(
                help_text="The name of the variable.", max_length=100
            ),
        ),
        migrations.AlterField(
            model_name="documenttemplatefreevariable",
            name="required",
            field=models.BooleanField(
                default=False,
                help_text="Signifies whether the variable is required or not.",
            ),
        ),
        migrations.AlterField(
            model_name="documenttemplatefreevariable",
            name="variable_type",
            field=models.CharField(
                choices=[
                    ("date", "Date"),
                    ("boolean", "Boolean"),
                    ("text", "Text"),
                    ("list", "List"),
                    ("integer", "Integer"),
                    ("float", "Decimal"),
                    ("model", "Model"),
                ],
                help_text="The type of the variable.",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="documenttemplatestyling",
            name="name",
            field=models.CharField(
                help_text="Name of the document template styling.", max_length=100
            ),
        ),
        migrations.AlterField(
            model_name="sqlqueryfilter",
            name="query",
            field=bloomerp.models.fields.CodeField(
                help_text="SQL Query to execute", language="sql"
            ),
        ),
    ]
