# Generated by Django 5.1.1 on 2024-10-06 13:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0014_accommodation_created_by_accommodation_updated_by_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="employee",
            name="date_of_birth",
            field=models.DateField(blank=True, null=True),
        ),
    ]
