{% extends "anonymous_base.html" %}
{% load crispy_forms_tags %}

{% block main %}

<div class="container">

<div
    class="row justify-content-center align-items-center g-2"
>
    
    <div class="col-6">
        <div class="card text-start">
            <div class="card-body">
                <h4 class="card-title">Password reset complete</h4>
                <p class="card-text">Your password has been set. You may go ahead and log in now.
                </p>
                <a href="{% url 'login' %}">Log in</a>

                

            </div>
        </div>
        

    </div>
    
</div>


    
    
</div>



{% endblock main %}
