# Generated by Django 5.1.1 on 2024-11-20 22:22

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0049_alter_file_options_alter_filefolder_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="applicationfield",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="bookmark",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="comment",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="documenttemplate",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="documenttemplatefreevariable",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="documenttemplateheader",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="documenttemplatestyling",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="link",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="sqlquery",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
                "verbose_name": "SQL Query",
                "verbose_name_plural": "SQL Queries",
            },
        ),
        migrations.AlterModelOptions(
            name="sqlqueryfilter",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
                "verbose_name": "SQL Query Filter",
                "verbose_name_plural": "SQL Query Filters",
            },
        ),
        migrations.AlterModelOptions(
            name="user",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                )
            },
        ),
        migrations.AlterModelOptions(
            name="userdetailviewpreference",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="userdetailviewtab",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="userlistviewpreference",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="workspace",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
    ]
