# Generated by Django 5.1.1 on 2024-12-29 18:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0027_alter_order_status"),
    ]

    operations = [
        migrations.AddField(
            model_name="employee",
            name="gender",
            field=models.CharField(
                blank=True,
                choices=[("M", "Male"), ("F", "Female"), ("O", "Other")],
                max_length=1,
                null=True,
            ),
        ),
    ]
