# Generated by Django 5.1.1 on 2024-12-13 18:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0054_documenttemplatefreevariable_help_text_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="documenttemplate",
            name="page_margin",
            field=models.FloatField(
                default=1.0, help_text="Margin of the document template in inches."
            ),
        ),
        migrations.AddField(
            model_name="documenttemplate",
            name="page_orientation",
            field=models.CharField(
                choices=[("portrait", "Portrait"), ("landscape", "Landscape")],
                default="portrait",
                help_text="Orientation of the document template.",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="documenttemplate",
            name="page_size",
            field=models.CharField(
                choices=[("A4", "A4"), ("letter", "Letter"), ("A3", "A3")],
                default="A4",
                help_text="Size of the document template.",
                max_length=10,
            ),
        ),
        migrations.AddField(
            model_name="documenttemplateheader",
            name="height",
            field=models.FloatField(
                default=1.0, help_text="Height of the header in inches."
            ),
        ),
        migrations.AddField(
            model_name="documenttemplateheader",
            name="margin_bottom",
            field=models.FloatField(
                default=0.0, help_text="Bottom margin of the header in inches."
            ),
        ),
        migrations.AddField(
            model_name="documenttemplateheader",
            name="margin_left",
            field=models.FloatField(
                default=1.0, help_text="Left margin of the header in inches."
            ),
        ),
        migrations.AddField(
            model_name="documenttemplateheader",
            name="margin_right",
            field=models.FloatField(
                default=1.0, help_text="Right margin of the header in inches."
            ),
        ),
        migrations.AddField(
            model_name="documenttemplateheader",
            name="margin_top",
            field=models.FloatField(
                default=0.5, help_text="Top margin of the header in inches."
            ),
        ),
        migrations.AlterField(
            model_name="documenttemplate",
            name="footer",
            field=models.TextField(
                blank=True,
                help_text="Footer content of the document template.",
                null=True,
            ),
        ),
    ]
