# Generated by Django 5.1.1 on 2024-09-27 00:28

import bloomerp.models.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0021_userdashboardview_delete_userkpilistviewpreference"),
    ]

    operations = [
        migrations.AlterField(
            model_name="sqlquery",
            name="query",
            field=bloomerp.models.fields.CodeField(
                help_text="SQL Query to execute", language="sql"
            ),
        ),
    ]
