{% extends "anonymous_base.html" %}
{% load crispy_forms_tags %}

{% block main %}

<div class="container">

<div
    class="row justify-content-center align-items-center g-2"
>
    
    <div class="col-6">
        <div class="card text-start">
            <div class="card-body">
                <h4 class="card-title">Enter new password</h4>
                
                

                <form method="post" action="">
                    {{form|crispy}}
                    {% csrf_token %}
                    <button
                        type="submit"
                        class="btn btn-primary"
                        
                    >
                        Reset password
                    </button>
                    
                </form>

            </div>
        </div>
        

    </div>
    
</div>


    
    
</div>



{% endblock main %}
