# Generated by Django 5.1.1 on 2024-10-05 20:27

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0030_alter_file_created_by_alter_file_updated_by_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="file",
            name="persisted",
            field=models.BooleanField(default=False),
        ),
    ]
