# Generated by Django 5.1.1 on 2024-12-29 21:05

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0059_documenttemplate_avatar_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="documenttemplate",
            name="save_to_folder",
            field=models.ForeignKey(
                blank=True,
                help_text="Signifies to which folder a file generated from the template needs to be saved upon creation.",
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bloomerp.filefolder",
            ),
        ),
    ]
