# Generated by Django 5.1.1 on 2024-11-20 22:07

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "test_app",
            "0019_alter_accommodation_options_alter_customer_options_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="accommodation",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                )
            },
        ),
        migrations.AlterModelOptions(
            name="customer",
            options={"verbose_name": "customer", "verbose_name_plural": "customers"},
        ),
        migrations.AlterModelOptions(
            name="employee",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                )
            },
        ),
        migrations.AlterModelOptions(
            name="employeeonaccommodation",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                )
            },
        ),
        migrations.AlterModelOptions(
            name="equipment",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                )
            },
        ),
        migrations.AlterModelOptions(
            name="function",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                )
            },
        ),
        migrations.AlterModelOptions(
            name="order",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                )
            },
        ),
        migrations.AlterModelOptions(
            name="product",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                )
            },
        ),
    ]
