# Generated by Django 5.1.1 on 2025-01-02 18:16

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0028_employee_gender"),
    ]

    operations = [
        migrations.AddField(
            model_name="order",
            name="date",
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
