# Generated by Django 5.1.1 on 2024-10-02 22:49

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0025_rename_folder_filefolder_alter_filefolder_options_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="filefolder",
            name="parent",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="bloomerp.filefolder",
            ),
        ),
    ]
