{% if form.form_html %}
    {% if include_media %}{{ form.media }}{% endif %}
    {% if form_show_errors %}
        {% include "bootstrap5/errors.html" %}
    {% endif %}
    {{ form.form_html }}
{% else %}
    {% include "bootstrap5/uni_form.html" %}
{% endif %}
