# Generated by Django 5.1.1 on 2024-09-26 17:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0011_function_employee_manager_employee_functions"),
    ]

    operations = [
        migrations.CreateModel(
            name="Equipment",
            fields=[
                ("datetime_created", models.DateTimeField(auto_now_add=True)),
                ("datetime_updated", models.DateTimeField(auto_now=True)),
                ("id", models.UUIDField(primary_key=True, serialize=False)),
                ("name", models.CharField(max_length=255)),
            ],
            options={
                "permissions": (
                    (
                        "bulk_delete%(class)s",
                        "Can delete multiple objects from %(class)s at once",
                    ),
                    (
                        "bulk_change%(class)s",
                        "Can update multiple objects from %(class)s at once",
                    ),
                ),
                "abstract": False,
            },
        ),
        migrations.AddField(
            model_name="employee",
            name="equipment",
            field=models.ManyToManyField(to="test_app.equipment"),
        ),
    ]
