/**
* Template Name: NiceAdmin - v2.2.2
* Template URL: https://bootstrapmade.com/nice-admin-bootstrap-admin-html-template/
* Author: BootstrapMade.com #4154f1
* License: https://bootstrapmade.com/license/#012970
*/

/*--------------------------------------------------------------
# General
--------------------------------------------------------------*/
:root {
  scroll-behavior: smooth;
  --primary: #4154f1;
  --primary-hover: #6776f4;
  --secondary: #646990;
  --dark: #012970;
  --main-light: #f6f9ff;
  --main-dark: #2c384e;
  --font-sans: "IBM Plex Sans", sans-serif;
}

body {
  font-family: var(--font-sans);
  background: var(--main-light);
  color: #444444;
}

a {
  color: var(--primary);
  text-decoration: none;
}

a:hover {
  color: #717ff5;
  text-decoration: none;
}

h1, h2, h3, h4, h5, h6 {
  font-family: var(--font-sans);
}

/*--------------------------------------------------------------
# Bootstrap
--------------------------------------------------------------*/
.btn-primary {
  background-color: var(--primary);
  border-color: var(--primary);
}

.btn-secondary {
  background-color: var(--secondary);
  border-color: var(--secondary);
}




/*--------------------------------------------------------------
# Main
--------------------------------------------------------------*/
#main {
  margin-top: 60px;
  padding: 20px 30px;
  transition: all 0.3s;
}
@media (max-width: 1199px) {
  #main {
    padding: 20px;
  }
}

/*--------------------------------------------------------------
# Page Title
--------------------------------------------------------------*/
.pagetitle {
  margin-bottom: 10px;
}
.pagetitle h1 {
  font-size: 24px;
  margin-bottom: 0;
  font-weight: 600;
  color: var(--dark);
}

/*--------------------------------------------------------------
# Back to top button
--------------------------------------------------------------*/
.back-to-top {
  position: fixed;
  visibility: hidden;
  opacity: 0;
  right: 15px;
  bottom: 15px;
  z-index: 99999;
  background: var(--primary);
  width: 40px;
  height: 40px;
  border-radius: 4px;
  transition: all 0.4s;
}
.back-to-top i {
  font-size: 24px;
  color: #fff;
  line-height: 0;
}
.back-to-top:hover {
  background: #6776f4;
  color: #fff;
}
.back-to-top.active {
  visibility: visible;
  opacity: 1;
}

/*--------------------------------------------------------------
# Override some default Bootstrap stylings
--------------------------------------------------------------*/
/* Dropdown menus */
.dropdown-menu {
  position: relative;
  border-radius: 4px;
  padding: 10px 0;
  -webkit-animation-name: dropdown-animate;
  animation-name: dropdown-animate;
  -webkit-animation-duration: 0.2s;
  animation-duration: 0.2s;
  -webkit-animation-fill-mode: both;
  animation-fill-mode: both;
  border: 0;
  box-shadow: 0 5px 30px 0 rgba(82, 63, 105, 0.2);
}
.dropdown-menu .dropdown-header, .dropdown-menu .dropdown-footer {
  text-align: center;
  font-size: 15px;
  padding: 10px 25px;
}
.dropdown-menu .dropdown-footer a {
  color: #444444;
  text-decoration: underline;
}
.dropdown-menu .dropdown-footer a:hover {
  text-decoration: none;
}
.dropdown-menu .dropdown-divider {
  color: #a5c5fe;
  margin: 0;
}
.dropdown-menu .dropdown-item {
  font-size: 14px;
  padding: 10px 15px;
  transition: 0.3s;
  position: relative;
}
.dropdown-menu .dropdown-item i {
  margin-right: 10px;
  font-size: 18px;
  line-height: 0;
}
.dropdown-menu .dropdown-item:hover {
  background-color: #f6f9ff;
}

/* Styles for nested dropdown to ensure it pops out */
.nested-dropdown {
  position: absolute; /* Positions it out of the flow, relative to nearest positioned ancestor */
  top: 0; /* Adjust these values as necessary to place the dropdown */
  left: 100%; /* Positions the nested dropdown to the right of the parent dropdown */
  max-height: 300px; /* Removes any max-height restriction */
  overflow-y: auto; /* Should help, but may not be necessary if positioning is handled correctly */
  z-index: 1050; /* Ensure it's above all relative layers */
  width: 500px; /* Adjust width as necessary */
  box-shadow: 0 5px 30px rgba(0,0,0,0.2); /* Optional: adds shadow to nested dropdown */
}

@media (min-width: 768px) {
  .dropdown-menu-arrow::before {
    content: "";
    width: 13px;
    height: 13px;
    background: #fff;
    position: absolute;
    top: -7px;
    right: 20px;
    transform: rotate(45deg);
    border-top: 1px solid #eaedf1;
    border-left: 1px solid #eaedf1;
  }
}
@-webkit-keyframes dropdown-animate {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
  0% {
    opacity: 0;
  }
}
@keyframes dropdown-animate {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
  0% {
    opacity: 0;
  }
}
/* Light Backgrounds */
.bg-primary-light {
  background-color: #cfe2ff;
  border-color: #cfe2ff;
}

.bg-secondary-light {
  background-color: #e2e3e5;
  border-color: #e2e3e5;
}

.bg-success-light {
  background-color: #d1e7dd;
  border-color: #d1e7dd;
}

.bg-danger-light {
  background-color: #f8d7da;
  border-color: #f8d7da;
}

.bg-warning-light {
  background-color: #fff3cd;
  border-color: #fff3cd;
}

.bg-info-light {
  background-color: #cff4fc;
  border-color: #cff4fc;
}

.bg-dark-light {
  background-color: #d3d3d4;
  border-color: #d3d3d4;
}

/* Card */
.card {
  border: none;
  border-radius: 5px;
  box-shadow: 0px 0 30px rgba(1, 41, 112, 0.1);
}

.card-header, .card-footer {
  border-color: #ebeef4;
  background-color: #fff;
  color: #798eb3;
  padding: 15px;
}

.card-title {
  padding: 20px 0 15px 0;
  font-size: 18px;
  font-weight: 600;
  color: var(--dark);
  font-weight: bold;
}
.card-title span {
  color: #899bbd;
  font-size: 14px;
  font-weight: 400;
}
.card-body {
  padding: 0 20px 20px 20px;
}

.card-img-overlay {
  background-color: rgba(255, 255, 255, 0.6);
}

/* Alerts */
.alert-heading {
  font-weight: 500;
  font-family: var(--font-sans);
  font-size: 20px;
}

/* Close Button */
.btn-close {
  background-size: 25%;
}
.btn-close:focus {
  outline: 0;
  box-shadow: none;
}

/* Accordion */
.accordion-item {
  border: 1px solid #ebeef4;
}

.accordion-button:focus {
  outline: 0;
  box-shadow: none;
}
.accordion-button:not(.collapsed) {
  color: var(--dark);
  background-color: #f6f9ff;
}

.accordion-flush .accordion-button {
  padding: 15px 0;
  background: none;
  border: 0;
}
.accordion-flush .accordion-button:not(.collapsed) {
  box-shadow: none;
  color: var(--primary);
}
.accordion-flush .accordion-body {
  padding: 0 0 15px 0;
  color: #3e4f6f;
  font-size: 15px;
}

/* Breadcrumbs */
.breadcrumb {
  font-size: 14px;
  font-family: var(--font-sans);
  color: #899bbd;
  font-weight: 600;
}
.breadcrumb a {
  color: #899bbd;
  transition: 0.3s;
}
.breadcrumb a:hover {
  color: #51678f;
}
.breadcrumb .breadcrumb-item::before {
  color: #899bbd;
}
.breadcrumb .active {
  color: #51678f;
  font-weight: 600;
}

/* Bordered Tabs */
.nav-tabs-bordered {
  border-bottom: 2px solid #ebeef4;
}
.nav-tabs-bordered .nav-link {
  margin-bottom: -2px;
  border: none;
  color: #2c384e;
}
.nav-tabs-bordered .nav-link:hover, .nav-tabs-bordered .nav-link:focus {
  color: var(--primary);
}
.nav-tabs-bordered .nav-link.active {
  background-color: #fff;
  color: var(--primary);
  border-bottom: 2px solid var(--primary);
}

/*--------------------------------------------------------------
# Header
--------------------------------------------------------------*/
.logo {
  line-height: 1;
}
@media (min-width: 1200px) {
  .logo {
    width: 280px;
  }
}
.logo img {
  max-height: 26px;
  margin-right: 6px;
}
.logo span {
  font-size: 26px;
  font-weight: 700;
  color: var(--dark);
  font-family: var(--font-sans);
}

.header {
  transition: all 0.5s;
  z-index: 997;
  height: 60px;
  box-shadow: 0px 2px 20px rgba(1, 41, 112, 0.1);
  background-color: #fff;
  padding-left: 20px;
  /* Toggle Sidebar Button */
  /* Search Bar */
}
.header .toggle-sidebar-button {
  font-size: 32px;
  padding-left: 10px;
  cursor: pointer;
  color: var(--dark);
}
.header .search-bar {
  min-width: 360px;
  padding: 0 20px;
}
@media (max-width: 1199px) {
  .header .search-bar {
    position: fixed;
    top: 50px;
    left: 0;
    right: 0;
    padding: 20px;
    box-shadow: 0px 0px 15px 0px rgba(1, 41, 112, 0.1);
    background: white;
    z-index: 9999;
    transition: 0.3s;
    visibility: hidden;
    opacity: 0;
  }
  .header .search-bar-show {
    top: 60px;
    visibility: visible;
    opacity: 1;
  }
}
.header .search-form {
  width: 100%;
}
.header .search-form input {
  border: 0;
  font-size: 14px;
  color: var(--dark);
  border: 1px solid rgba(1, 41, 112, 0.2);
  padding: 7px 38px 7px 8px;
  border-radius: 3px;
  transition: 0.3s;
  width: 100%;
}
.header .search-form input:focus, .header .search-form input:hover {
  outline: none;
  box-shadow: 0 0 10px 0 rgba(1, 41, 112, 0.15);
  border: 1px solid rgba(1, 41, 112, 0.3);
}
.header .search-form button {
  border: 0;
  padding: 0;
  margin-left: -30px;
  background: none;
}
.header .search-form button i {
  color: var(--dark);
}

/*--------------------------------------------------------------
# Header Nav
--------------------------------------------------------------*/
.header-nav ul {
  list-style: none;
}
.header-nav > ul {
  margin: 0;
  padding: 0;
}
.header-nav .nav-icon {
  font-size: 20px;
  color: var(--dark);
}
.header-nav .nav-profile {
  color: var(--dark);
}
.header-nav .nav-profile img {
  max-height: 36px;
}
.header-nav .nav-profile span {
  font-size: 14px;
  font-weight: 600;
}
.header-nav .badge-number {
  position: absolute;
  inset: 4px 6px auto auto;
  font-weight: normal;
  font-size: 11px;
  padding: 3px 6px;
}
.header-nav .notifications .notification-item {
  display: flex;
  align-items: center;
  padding: 15px 10px;
  transition: 0.3s;
}
.header-nav .notifications .notification-item i {
  margin: 0 20px 0 10px;
  font-size: 24px;
}
.header-nav .notifications .notification-item h4 {
  font-size: 16px;
  font-weight: 600;
  margin-bottom: 5px;
}
.header-nav .notifications .notification-item p {
  font-size: 13px;
  margin-bottom: 3px;
  color: #919191;
}
.header-nav .notifications .notification-item:hover {
  background-color: #f6f9ff;
}
.header-nav .messages .message-item {
  padding: 15px 10px;
  transition: 0.3s;
}
.header-nav .messages .message-item a {
  display: flex;
}
.header-nav .messages .message-item img {
  margin: 0 20px 0 10px;
  max-height: 40px;
}
.header-nav .messages .message-item h4 {
  font-size: 16px;
  font-weight: 600;
  margin-bottom: 5px;
  color: #444444;
}
.header-nav .messages .message-item p {
  font-size: 13px;
  margin-bottom: 3px;
  color: #919191;
}
.header-nav .messages .message-item:hover {
  background-color: #f6f9ff;
}
.header-nav .profile {
  min-width: 240px;
  padding-bottom: 0;
}
.header-nav .profile .dropdown-header h6 {
  font-size: 18px;
  margin-bottom: 0;
  font-weight: 600;
  color: #444444;
}
.header-nav .profile .dropdown-header span {
  font-size: 14px;
}
.header-nav .profile .dropdown-item {
  font-size: 14px;
  padding: 10px 15px;
  transition: 0.3s;
}
.header-nav .profile .dropdown-item i {
  margin-right: 10px;
  font-size: 18px;
  line-height: 0;
}
.header-nav .profile .dropdown-item:hover {
  background-color: #f6f9ff;
}

/*--------------------------------------------------------------
# Sidebar
--------------------------------------------------------------*/
.sidebar {
  position: fixed;
  top: 60px;
  left: 0;
  bottom: 0;
  width: 300px;
  z-index: 996;
  transition: all 0.3s;
  padding: 20px;
  overflow-y: auto;
  scrollbar-width: thin;
  scrollbar-color: #aab7cf transparent;
  box-shadow: 0px 0px 20px rgba(1, 41, 112, 0.1);
  background-color: #fff;
}
@media (max-width: 1199px) {
  .sidebar {
    left: -300px;
  }
}
.sidebar::-webkit-scrollbar {
  width: 5px;
  height: 8px;
  background-color: #fff;
}
.sidebar::-webkit-scrollbar-thumb {
  background-color: #aab7cf;
}

@media (min-width: 1200px) {
  #main, #footer {
    margin-left: 300px;
  }
}
@media (max-width: 1199px) {
  .toggle-sidebar .sidebar {
    left: -300px; /* Hidden by default */
  }
  .sidebar {
    left: 0; /* Show sidebar when toggle-sidebar class is added */
  }
}
@media (min-width: 1200px) {
  .toggle-sidebar #main, .toggle-sidebar #footer {
    margin-left: 0;
  }
  .toggle-sidebar .sidebar {
    left: -300px;
  }
}

.sidebar-nav {
  padding: 0;
  margin: 0;
  list-style: none;
}
.sidebar-nav li {
  padding: 0;
  margin: 0;
  list-style: none;
}
.sidebar-nav .nav-item {
  margin-bottom: 5px;
}
.sidebar-nav .nav-heading {
  font-size: 11px;
  text-transform: uppercase;
  color: #899bbd;
  font-weight: 600;
  margin: 10px 0 5px 15px;
}
.sidebar-nav .nav-link {
  display: flex;
  align-items: center;
  font-size: 15px;
  font-weight: 600;
  color: var(--primary);
  transition: 0.3;
  background: #f6f9ff;
  padding: 10px 15px;
  border-radius: 4px;
}
.sidebar-nav .nav-link i {
  font-size: 16px;
  margin-right: 10px;
  color: var(--primary);
}
.sidebar-nav .nav-link.collapsed {
  color: var(--dark);
  background: #fff;
}
.sidebar-nav .nav-link.collapsed i {
  color: #899bbd;
}
.sidebar-nav .nav-link:hover {
  color: var(--primary);
  background: #f6f9ff;
}
.sidebar-nav .nav-link:hover i {
  color: var(--primary);
}
.sidebar-nav .nav-link .bi-chevron-down {
  margin-right: 0;
  transition: transform 0.2s ease-in-out;
}
.sidebar-nav .nav-link:not(.collapsed) .bi-chevron-down {
  transform: rotate(180deg);
}
.sidebar-nav .nav-content {
  padding: 5px 0 0 0;
  margin: 0;
  list-style: none;
}
.sidebar-nav .nav-content a {
  display: flex;
  align-items: center;
  font-size: 14px;
  font-weight: 600;
  color: var(--dark);
  transition: 0.3;
  padding: 10px 0 10px 40px;
  transition: 0.3s;
}
.sidebar-nav .nav-content a i {
  font-size: 6px;
  margin-right: 8px;
  line-height: 0;
  border-radius: 50%;
}
.sidebar-nav .nav-content a:hover, .sidebar-nav .nav-content a.active {
  color: var(--primary);
}
.sidebar-nav .nav-content a.active i {
  background-color: var(--primary);
}

/*--------------------------------------------------------------
# Dashboard
--------------------------------------------------------------*/
/* Filter dropdown */
.dashboard .filter {
  position: absolute;
  right: 0px;
  top: 15px;
}
.dashboard .filter .icon {
  color: #aab7cf;
  padding-right: 20px;
  padding-bottom: 5px;
  transition: 0.3s;
  font-size: 16px;
}
.dashboard .filter .icon:hover, .dashboard .filter .icon:focus {
  color: var(--primary);
}
.dashboard .filter .dropdown-header {
  padding: 8px 15px;
}
.dashboard .filter .dropdown-header h6 {
  text-transform: uppercase;
  font-size: 14px;
  font-weight: 600;
  letter-spacing: 1px;
  color: #aab7cf;
  margin-bottom: 0;
  padding: 0;
}
.dashboard .filter .dropdown-item {
  padding: 8px 15px;
}

/* Info Cards */
.dashboard .info-card {
  padding-bottom: 10px;
}
.dashboard .info-card h6 {
  font-size: 28px;
  color: var(--dark);
  font-weight: 700;
  margin: 0;
  padding: 0;
}
.dashboard .card-icon {
  font-size: 32px;
  line-height: 0;
  width: 64px;
  height: 64px;
  flex-shrink: 0;
  flex-grow: 0;
}
.dashboard .sales-card .card-icon {
  color: var(--primary);
  background: #f6f6fe;
}
.dashboard .revenue-card .card-icon {
  color: #2eca6a;
  background: #e0f8e9;
}
.dashboard .customers-card .card-icon {
  color: #ff771d;
  background: #ffecdf;
}

/* Activity */
.dashboard .activity {
  font-size: 14px;
}
.dashboard .activity .activity-item .activite-label {
  color: #888;
  position: relative;
  flex-shrink: 0;
  flex-grow: 0;
  min-width: 64px;
}
.dashboard .activity .activity-item .activite-label::before {
  content: "";
  position: absolute;
  right: -11px;
  width: 4px;
  top: 0;
  bottom: 0;
  background-color: #eceefe;
}
.dashboard .activity .activity-item .activity-badge {
  margin-top: 3px;
  z-index: 1;
  font-size: 11px;
  line-height: 0;
  border-radius: 50%;
  flex-shrink: 0;
  border: 3px solid #fff;
  flex-grow: 0;
}
.dashboard .activity .activity-item .activity-content {
  padding-left: 10px;
  padding-bottom: 20px;
}
.dashboard .activity .activity-item:first-child .activite-label::before {
  top: 5px;
}
.dashboard .activity .activity-item:last-child .activity-content {
  padding-bottom: 0;
}

/* News & Updates */
.dashboard .news .post-item + .post-item {
  margin-top: 15px;
}
.dashboard .news img {
  width: 80px;
  float: left;
  border-radius: 5px;
}
.dashboard .news h4 {
  font-size: 15px;
  margin-left: 95px;
  font-weight: bold;
  margin-bottom: 5px;
}
.dashboard .news h4 a {
  color: var(--dark);
  transition: 0.3s;
}
.dashboard .news h4 a:hover {
  color: var(--primary);
}
.dashboard .news p {
  font-size: 14px;
  color: #777777;
  margin-left: 95px;
}

/* Recent Sales */
.dashboard .recent-sales {
  font-size: 14px;
}
.dashboard .recent-sales .table thead {
  background: #f6f6fe;
}
.dashboard .recent-sales .table thead th {
  border: 0;
}
.dashboard .recent-sales .dataTable-top {
  padding: 0 0 10px 0;
}
.dashboard .recent-sales .dataTable-bottom {
  padding: 10px 0 0 0;
}

/* Top Selling */
.dashboard .top-selling {
  font-size: 14px;
}
.dashboard .top-selling .table thead {
  background: #f6f6fe;
}
.dashboard .top-selling .table thead th {
  border: 0;
}
.dashboard .top-selling .table tbody td {
  vertical-align: middle;
}
.dashboard .top-selling img {
  border-radius: 5px;
  max-width: 60px;
}

/*--------------------------------------------------------------
# Icons list page
--------------------------------------------------------------*/
.iconslist {
  display: grid;
  max-width: 100%;
  grid-template-columns: repeat(auto-fit, minmax(180px, 1fr));
  gap: 1.25rem;
  padding-top: 15px;
}
.iconslist .icon {
  background-color: #fff;
  border-radius: 0.25rem;
  text-align: center;
  color: var(--dark);
  padding: 15px 0;
}
.iconslist i {
  margin: 0.25rem;
  font-size: 2.5rem;
}
.iconslist .label {
  font-family: var(--bs-font-monospace);
  display: inline-block;
  width: 100%;
  overflow: hidden;
  padding: 0.25rem;
  font-size: 12px;
  text-overflow: ellipsis;
  white-space: nowrap;
  color: #666;
}

/*--------------------------------------------------------------
# Profie Page
--------------------------------------------------------------*/
.profile .profile-card img {
  max-width: 120px;
}
.profile .profile-card h2 {
  font-size: 24px;
  font-weight: 700;
  color: #2c384e;
  margin: 10px 0 0 0;
}
.profile .profile-card h3 {
  font-size: 18px;
}
.profile .profile-card .social-links a {
  font-size: 20px;
  display: inline-block;
  color: rgba(1, 41, 112, 0.5);
  line-height: 0;
  margin-right: 10px;
  transition: 0.3s;
}
.profile .profile-card .social-links a:hover {
  color: var(--dark);
}
.profile .profile-overview .row {
  margin-bottom: 20px;
  font-size: 15px;
}
.profile .profile-overview .card-title {
  color: var(--dark);
}
.profile .profile-overview .label {
  font-weight: 600;
  color: rgba(1, 41, 112, 0.6);
}
.profile .profile-edit label {
  font-weight: 600;
  color: rgba(1, 41, 112, 0.6);
}
.profile .profile-edit img {
  max-width: 120px;
}

/*--------------------------------------------------------------
# F.A.Q Page
--------------------------------------------------------------*/
.faq .basic h6 {
  font-size: 18px;
  font-weight: 600;
  color: var(--primary);
}
.faq .basic p {
  color: #6980aa;
}

/*--------------------------------------------------------------
# Contact
--------------------------------------------------------------*/
.contact .info-box {
  padding: 28px 30px;
}
.contact .info-box i {
  font-size: 38px;
  line-height: 0;
  color: var(--primary);
}
.contact .info-box h3 {
  font-size: 20px;
  color: var(--dark);
  font-weight: 700;
  margin: 20px 0 10px 0;
}
.contact .info-box p {
  padding: 0;
  line-height: 24px;
  font-size: 14px;
  margin-bottom: 0;
}
.contact .php-email-form .error-message {
  display: none;
  color: #fff;
  background: #ed3c0d;
  text-align: left;
  padding: 15px;
  margin-bottom: 24px;
  font-weight: 600;
}
.contact .php-email-form .sent-message {
  display: none;
  color: #fff;
  background: #18d26e;
  text-align: center;
  padding: 15px;
  margin-bottom: 24px;
  font-weight: 600;
}
.contact .php-email-form .loading {
  display: none;
  background: #fff;
  text-align: center;
  padding: 15px;
  margin-bottom: 24px;
}
.contact .php-email-form .loading:before {
  content: "";
  display: inline-block;
  border-radius: 50%;
  width: 24px;
  height: 24px;
  margin: 0 10px -6px 0;
  border: 3px solid #18d26e;
  border-top-color: #eee;
  -webkit-animation: animate-loading 1s linear infinite;
  animation: animate-loading 1s linear infinite;
}
.contact .php-email-form input, .contact .php-email-form textarea {
  border-radius: 0;
  box-shadow: none;
  font-size: 14px;
  border-radius: 0;
}
.contact .php-email-form input:focus, .contact .php-email-form textarea:focus {
  border-color: var(--primary);
}
.contact .php-email-form input {
  padding: 10px 15px;
}
.contact .php-email-form textarea {
  padding: 12px 15px;
}
.contact .php-email-form button[type=submit] {
  background: var(--primary);
  border: 0;
  padding: 10px 30px;
  color: #fff;
  transition: 0.4s;
  border-radius: 4px;
}
.contact .php-email-form button[type=submit]:hover {
  background: #5969f3;
}
@-webkit-keyframes animate-loading {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}
@keyframes animate-loading {
  0% {
    transform: rotate(0deg);
  }
  100% {
    transform: rotate(360deg);
  }
}

/*--------------------------------------------------------------
# Error 404
--------------------------------------------------------------*/
.error-404 {
  padding: 30px;
}
.error-404 h1 {
  font-size: 180px;
  font-weight: 700;
  color: var(--primary);
  margin-bottom: 0;
  line-height: 150px;
}
.error-404 h2 {
  font-size: 24px;
  font-weight: 700;
  color: var(--dark);
  margin-bottom: 30px;
}
.error-404 .btn {
  background: #51678f;
  color: #fff;
  padding: 8px 30px;
}
.error-404 .btn:hover {
  background: #3e4f6f;
}
@media (min-width: 992px) {
  .error-404 img {
    max-width: 50%;
  }
}

/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/
.footer {
  padding: 20px 0;
  font-size: 14px;
  transition: all 0.3s;
  border-top: 1px solid #cddfff;
}
.footer .copyright {
  text-align: center;
  color: var(--dark);
}
.footer .credits {
  padding-top: 5px;
  text-align: center;
  font-size: 13px;
  color: var(--dark);
}

/*--------------------------------------------------------------
# Custom
--------------------------------------------------------------*/
.timesheet-entry {
  padding: 2px;
}

.timesheet-entry:hover {
  border: 1px solid;
  border-radius: 1;
}


.filter-section .bi-plus-lg {
  display: flex;
  flex-wrap: wrap;
  justify-content: flex;
}

.filter-section .filter-item {
  background-color:rgb(235, 235, 235);
  padding: 8px;
  padding-left: 15px;
  padding-right: 15px;
  border-radius: 10px;
  margin: 10px;
}

.filter-section .filter-item:hover {
  background-color:rgb(238, 238, 238);
}

.dropdown-menu.filter-dropdown-menu {
  padding: 10px;
  width: 30vw;
}

@media (max-width: 576px) {
  .dropdown-menu.filter-dropdown-menu {
    width: 100vw;
  }
}


.pointer {
  cursor: pointer;
}

.pointer:hover {
  color: var(--primary-hover);
}

.copy-icon {
  cursor: pointer; /* Changes the cursor to indicate the icon is clickable */
  margin-left: 5px; /* Adds a little space between the text and the icon */
  position: relative;
  size: 2;
}

.copy-icon:hover {
  color: #b5d2fd;
}

.list-view-avatar {
  width: 35px;
  height: 35px;
  border-radius: 50%;
  object-fit: cover;
}


.label-container {
  display: flex;
  flex-wrap: wrap;
  justify-content: start;
  color: white;
}

.label-span {
  display: flex;
  flex-wrap: wrap;
  margin-right: 4px;
  margin-bottom: 4px;
  padding: 7px;
  background-color: var(--primary);
  cursor: pointer;
}

.label-span:hover {
  background-color: #6776f4;
}

/* 
Dashboard
*/

.draggable {
  cursor: move;
}

.drag-over {
  background-color: #e3ebfc;
  border: 1px dashed var(--dark);
  padding: 10px;
  margin: 10px;
}

.dropzone-container {
  background-color: var(--main-light);
}

.dropzone-row {
  background-color: #edf3ff;
  border: 1px dashed #b5b5b5;
  padding: 20px;
  margin: 20px;
}

.dropzone-row.dropzone-row-add-col {
  position:absolute;
  top: 0;
}

.dropzone-col.dragover {
  background-color: #6e7685;
  border: 1px dashed var(--dark);
  z-index: 1000;

}

.save-layout-div {
  position: fixed;
  bottom: 15px; /* Distance from the bottom */
  right: 60px;  /* Distance from the right */
  z-index: 1000; /* Ensure it appears above other elements */
  background-color: transparent;
}

.href {
  cursor: pointer;
  color : var(--primary);
}

.file-breadcrumb-item {
  color: var(--dark);
  font-size:x-large;
  font-weight: bold;
}

.checkmark {
  color: var(--main-dark);
  font-size: 20px;
  margin-left: 5px;
  position: absolute;
  top: -5px;
  right: -5px;
}


.htmx-indicator{
  display:none;
  width: 20px;
  height: 20px;
}
.htmx-request .htmx-indicator{
  display:inline;
  justify-content:center;
  align-items:center;
}
.htmx-request.htmx-indicator{
  display:inline;
}

/* 
  CSS for content layout
*/
.content-layout-row {
  background-color: #edf3ff;
  border: 1px dashed #b5b5b5;
  padding: 10px;
  margin: 10px;
}

.content-layout-column {
  background-color: #c9dafc;
  border: 1px solid #b5b5b5;
  padding: 5px;
  margin: 5px;
}

.content-layout-column.dragover {
  background-color: #6e7685;
  border: 1px dashed var(--dark);
}

.content-layout-column.draggable {
  cursor: move;
}

.content-layout-item {
  background-color: #bed3fd;
  border: 1px solid #b5b5b5;
  padding: 5px;
  margin: 5px;
}


.is-loading {
  background: #eee;
  background: linear-gradient(110deg, #ececec 8%, #f5f5f5 18%, #ececec 33%);
  border-radius: 5px;
  background-size: 200% 100%;
  animation: 1.5s shine linear infinite;
  z-index: 1000;
}

@keyframes shine {
  to {
    background-position-x: -200%;
  }
}

/* 
  Alert messages
*/
/* Wrapper to hold all messages */
.messages-wrapper {
  position: fixed;
  bottom: 40px; /* Distance from the bottom */
  right: 60px;  /* Distance from the right */
  z-index: 1100; /* Ensure it appears above other elements */
  display: flex;
  flex-direction: column; /* Stack messages vertically */
  gap: 10px; /* Space between messages */
}

/* Common styles for all message containers */
.message-container {
  padding: 15px 20px;
  border-radius: 8px;
  box-shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
  min-width: 400px; /* Optional: Set a minimum width */
  max-width: 600px; /* Optional: Set a maximum width */
  opacity: 1; /* Initial opacity */
  transition: opacity 0.5s ease-out, transform 0.5s ease-out; /* Transition for fade-out and slight upward movement */
}

/* Specific styles for error messages */
.alert-message-error {
  background-color: #f8d7da; /* Light red background */
  color: #721c24;           /* Dark red text */
}

/* Specific styles for success messages */
.alert-message-success {
  background-color: #d4edda; /* Light green background */
  color: #155724;           /* Dark green text */
}

/* Styles for the inner message content */
.alert-message {
  font-size: 14px;
  display: flex;
  align-items: center;
  justify-content: space-between;
}

.alert-message-info {
  background-color: #cce5ff; /* Light blue background */
  color: #004085;           /* Dark blue text */
}

.alert-message-warning {
  background-color: #fff3cd; /* Light yellow background */
  color: #856404;           /* Dark yellow text */
}

.alert-icon {
  padding-right: 5px;
  height: 24px;
}

.alert-close {
  cursor: pointer;
  height: 20px;
}

.fade-out {
  opacity: 0;
  transform: translateY(-20px); /* Optional: Move the message slightly upwards */
}

.spinner-container {
  display: flex;
  justify-content: center;
  align-items: center;
  height: 50vh;
}

/* 
  LLM CSS
*/
.assistant-bubble {
  background-color: white;
  color: black;
  padding: 10px;
  border-radius: 10px;
  max-width: 75%;
  word-wrap: break-word;
  border: var(--primary) 2px solid;
}
.user-bubble {
  background-color: var(--primary);
  color: #fff;
  padding: 10px;
  border-radius: 10px;
  max-width: 75%;
  word-wrap: break-word;
}

/* 
  Signature css
*/

.signature-canvas {
  border: 1px solid #ced4da;
  border-radius: 0.25rem;
  width: 100%;
  height: 200px;
  touch-action: none; 
}

.initials {
  display: flex;
  align-items: center;
  justify-content: center;
  background-color: gray;
  color: white;
}

/* 
  Context menu
*/

.context-menu {
  display: none;
  position: absolute;
  z-index: 1000;
  background-color: #fff;
  border: 1px solid #ccc;
  border-radius: 5px;
  padding: 5px;
}

/*
  Legend
*/

.form-legend {
  font-weight: 500;
  font-size: 18px;
  color: var(--main-dark);
  font-weight: bold;
  font-family: var(--font-sans);
}

/* Full callendar */

.fc .fc-button-primary {
  background-color: var(--primary);
  border-color: var(--primary);
  color: white;
}

.dot {
  display: inline-block;
  width: 10px;
  height: 10px;
  border-radius: 50%; /* Makes it circular */
}


.full-screen {
  background-color: #f8f9fa;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 100vh;
  width: 100vw;
  position: fixed;
  top: 0;
  left: 0;
  z-index: 1050; /* Ensure it's above other elements */
}

.underline {
  text-decoration: underline;
}

/* Meta text */
.text-meta {
  font-size: 12px;
  color: #6c757d;
}