# Generated by Django 5.1.1 on 2024-12-13 18:53

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0055_documenttemplate_page_margin_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="documenttemplate",
            name="include_page_numbers",
            field=models.BooleanField(
                default=True,
                help_text="Signifies whether the page numbers are included or not.",
            ),
        ),
        migrations.AlterField(
            model_name="documenttemplate",
            name="footer",
            field=models.TextField(
                default="", help_text="Footer content of the document template."
            ),
        ),
    ]
