{% load bloomerp %}

{% breadcrumb title="My bookmarks" %}

<div class="card text-start">
    <div class="card-body">
        <h4 class="card-title">My bookmarks</h4>
        {% datatable content_type_id=content_type_id user=request.user initial_query=initial_query bypass_view_permission=True %}
    </div>
</div>




