{% load bloomerp %}

{% breadcrumb model=model title="Files" %}

<div class="card text-start">
    <div class="card-body m-2">
		<h1 class="card-title">View files</h1>

        {% include "snippets/files_snippet.html" %}
    </div>
</div>


