{% load static %}

<div
    class="table-responsive"
>
    <table
        class="table datatable"
    >
        <thead>
            <tr>
                {% for column in column_names %}
                    <th scope="col">{{ column }}</th>
                {% endfor %}
            </tr>
        </thead>
        <tbody>
            {% for row in data %}
            <tr>
                {% for cell in row %}
                    <td>{{ cell }}</td>
                {% endfor %}
            </tr>
            {% endfor %}
        </tbody>
    </table>
</div>



{% block scripts %}

<script src="{% static 'bloomerp/js/main.js' %}"></script>

{% endblock scripts %}