# Generated by Django 5.1.1 on 2024-11-05 19:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0042_rename_kpi_widget_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="applicationfield",
            name="db_column",
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
