# Generated by Django 5.1.1 on 2024-10-30 18:10

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0037_alter_documenttemplatestyling_styling_and_more"),
    ]

    operations = [
        migrations.DeleteModel(
            name="UserDetailViewTabs",
        ),
    ]
