# Generated by Django 5.1.1 on 2024-09-27 11:31

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0022_alter_sqlquery_query"),
    ]

    operations = [
        migrations.AddField(
            model_name="userdashboardview",
            name="layout",
            field=models.JSONField(
                blank=True, help_text="The layout of the dashboard", null=True
            ),
        ),
    ]
