{% load static %}
{% load crispy_forms_tags %}
{% load bloomerp %}

{% breadcrumb model=model title=title %}

<!--Form card-->
<div class="card">
	<div class="card-body">
		<h4 class="card-title">Create {{model_name}}</h4>
		{% if form.errors %}
		<div class="alert alert-danger" role="alert">
			{{form.errors}}
		</div>
		{% endif %}

		<form method="post" action="" enctype="multipart/form-data" class="px-3" data="dsa">
			{% csrf_token %}
			
			{% if form.helper %}{% crispy form %}{% else %}{{form|crispy}}{% endif %}

			<div class="d-flex justify-content-center gap-2">
				<button type="submit" class="btn btn-primary">Create {{ model_name }}</button>
				<button type="reset" class="btn btn-secondary" href="#">Reset</button>
			</div>
		
		</form>
	</div>
</div>
<!--End Form card-->


