# Generated by Django 5.1.1 on 2025-01-10 19:13

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0066_rename_requested_for_todo_assigned_to"),
    ]

    operations = [
        migrations.AlterField(
            model_name="todo",
            name="required_by",
            field=models.DateField(
                blank=True,
                help_text="The date by which the todo is required",
                null=True,
            ),
        ),
    ]
