# Generated by Django 5.1.1 on 2025-01-08 00:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0062_alter_sqlqueryfilter_data_type_todo"),
    ]

    operations = [
        migrations.RenameField(
            model_name="todo",
            old_name="user",
            new_name="requested_for",
        ),
        migrations.AddField(
            model_name="todo",
            name="title",
            field=models.CharField(
                default=1, help_text="The name of the todo", max_length=255
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="todo",
            name="content",
            field=models.TextField(blank=True, null=True),
        ),
    ]
