# Generated by Django 5.1.1 on 2024-11-20 22:04

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "test_app",
            "0018_alter_accommodation_options_alter_customer_options_and_more",
        ),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="accommodation",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="customer",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                ),
                "verbose_name": "customer",
                "verbose_name_plural": "customers",
            },
        ),
        migrations.AlterModelOptions(
            name="employee",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="employeeonaccommodation",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="equipment",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="function",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="order",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="product",
            options={
                "permissions": (
                    (
                        "bulk_delete_%(class)s",
                        "Can delete multiple objects from %(verbose_name)s at once ",
                    ),
                    (
                        "bulk_change_%(class)s",
                        "Can update multiple objects from %(verbose_name)s at once",
                    ),
                )
            },
        ),
    ]
