# Generated by Django 5.1.1 on 2024-11-20 23:54

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0051_alter_applicationfield_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="sqlquery",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                    "export",
                ),
                "managed": True,
                "permissions": [("execute_sql_query", "Can execute SQL queries")],
                "verbose_name": "SQL Query",
                "verbose_name_plural": "SQL Queries",
            },
        ),
    ]
