# Generated by Django 5.1.1 on 2025-01-11 21:05

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0070_alter_comment_object_id_alter_file_object_id_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="aiconversation",
            name="auto_named",
            field=models.BooleanField(
                default=False, help_text="Whether the conversation has been auto-named"
            ),
        ),
    ]
