# Generated by Django 5.1.1 on 2024-09-23 21:01

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0017_bookmark"),
    ]

    operations = [
        migrations.CreateModel(
            name="DocumentTemplateStyling",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("datetime_created", models.DateTimeField(auto_now_add=True)),
                ("datetime_updated", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(max_length=100)),
                ("styling", models.TextField(default="")),
            ],
            options={
                "db_table": "bloomerp_document_template_styling",
                "managed": True,
            },
        ),
        migrations.AddField(
            model_name="documenttemplate",
            name="styling",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.SET_NULL,
                to="bloomerp.documenttemplatestyling",
            ),
        ),
    ]
