# Generated by Django 5.1.1 on 2024-09-15 22:11

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0002_alter_customer_options_alter_order_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="order",
            options={
                "permissions": [
                    (
                        "bulk_delete_%(class)",
                        "Can delete multiple objects from %(class) at once",
                    ),
                    (
                        "bulk_change_%(class)",
                        "Can update multiple objects from %(class) at once",
                    ),
                ]
            },
        ),
        migrations.AlterModelOptions(
            name="product",
            options={
                "permissions": [
                    (
                        "bulk_delete_%(class)",
                        "Can delete multiple objects from %(class) at once",
                    ),
                    (
                        "bulk_change_%(class)",
                        "Can update multiple objects from %(class) at once",
                    ),
                ]
            },
        ),
    ]
