{% load static %}
{% load crispy_forms_tags %}
{% load globals %}
{% load i18n %}

<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="utf-8">
	<meta content="width=device-width, initial-scale=1.0" name="viewport">

	<title>Login</title>
	<meta content="" name="description">
	<meta content="" name="keywords">

	<!-- Favicons -->
	<link href="{% static 'bloomerp/img/favicon.png' %}" rel="icon">
	<link href="{% static 'bloomerp/img/apple-touch-icon.png' %}" rel="apple-touch-icon">

	<!-- Google Fonts -->
	<link href="https://fonts.gstatic.com" rel="preconnect">
	<link href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i|Nunito:300,300i,400,400i,600,600i,700,700i|Poppins:300,300i,400,400i,500,500i,600,600i,700,700i" rel="stylesheet">

	<!-- Vendor CSS Files -->
	<link href="{% static 'bloomerp/vendor/bootstrap/css/bootstrap.min.css' %}" rel="stylesheet">
	<link href="{% static 'bloomerp/vendor/bootstrap-icons/bootstrap-icons.css' %}" rel="stylesheet">

	<!-- Template Main CSS File -->
	<link href="{% static 'bloomerp/css/style.css' %}" rel="stylesheet">

</head>

<body>

  <main>
    <div class="container">

      <section class="section register min-vh-100 d-flex flex-column align-items-center justify-content-center py-4">
        <div class="container">
          <div class="row justify-content-center">
            <div class="col-lg-4 col-md-6 d-flex flex-column align-items-center justify-content-center">

              <div class="d-flex justify-content-center py-4">
                <a href="index.html" class="logo d-flex align-items-center w-auto">
                  <img src="{% static 'bloomerp/img/logo.png' %}" alt="">
                </a>
              </div><!-- End Logo -->

              <div class="card mb-3">

                <div class="card-body">
                  <div class="pt-4 pb-2">
                    <h5 class="card-title text-center pb-0 fs-4">{% trans "Login to Your Account" %}</h5>
                    <p class="text-center small">{% trans "Enter your username & password to login" %}</p>
                  </div>

                  <form class="row g-3 needs-validation" action="" method='POST'>
                    {% csrf_token %}
                    {{form | crispy}}
                    
                    <div class="col-12">
                      <button class="btn btn-primary w-100" type="submit">{% trans "Login" %}</button>
                    </div>
                    
                  </form>
                  <hr class="mt-3">
                  <p class="text-center text-muted mt-2">{% trans "Forgot password?" %}</p>
                  <p class="text-center"><a class="mt-2" href="">{% trans "Reset password" %}</a> {% trans "or contact your staff." %}</p>

                </div>
              </div>

              <div class="credits">
                {% trans "Designed by " %}<a>Bloomerp</a>
              </div>

            </div>
          </div>
        </div>

      </section>

    </div>
  </main><!-- End #main -->

  <a href="#" class="back-to-top d-flex align-items-center justify-content-center"><i class="bi bi-arrow-up-short"></i></a>

  <!-- Vendor JS Files -->
  <script src="{% static 'bloomerp/vendor/bootstrap/js/bootstrap.bundle.min.js' %}"></script>

  <!-- Template Main JS File -->
  <script src="{% static 'bloomerp/js/main.js' %}"></script>

</body>

</html>