
{% load static %}
{% load bloomerp %}
{% load crispy_forms_tags %}

<!-- Page Title -->
{% breadcrumb title=title model=model %}

<div class="card">
  	<div class="card-body">
		<h4 class="card-title">{{model_name_plural|title}} list</h4>
		{% datatable content_type_id=content_type_id user=request.user request=request %}

		<div class="d-md-flex justify-content-center gap-2 mt-3">
			<a class="btn btn-primary d-block" href="{% url create_view_url %}">Add {{ model_name }}</a>
			<a class="btn btn-secondary mt-2 mt-md-0 d-block" href="{% url bulk_upload_url %}">Bulk upload {{ model_name_plural }}</a>
		</div>

	</div>
</div>



