# Generated by Django 5.1.1 on 2024-10-20 20:25

import bloomerp.models.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0036_alter_link_level_userdetailviewtabs"),
    ]

    operations = [
        migrations.AlterField(
            model_name="documenttemplatestyling",
            name="styling",
            field=bloomerp.models.fields.CodeField(default="", language="css"),
        ),
        migrations.AlterField(
            model_name="user",
            name="avatar",
            field=models.ImageField(
                blank=True, help_text="The user's avatar", null=True, upload_to="users/"
            ),
        ),
        migrations.AlterField(
            model_name="user",
            name="date_view_preference",
            field=models.CharField(
                choices=[
                    ("d-m-Y", "Day-Month-Year (15-08-2000)"),
                    ("m-d-Y", "Month-Day-Year (08-15-2000)"),
                    ("Y-m-d", "Year-Month-Day (2000-08-15)"),
                ],
                default="d-m-Y",
                help_text="The date format to be used in the application",
                max_length=20,
            ),
        ),
        migrations.AlterField(
            model_name="user",
            name="datetime_view_preference",
            field=models.CharField(
                choices=[
                    ("d-m-Y H:i", "Day-Month-Year Hour:Minute (15-08-2000 12:30)"),
                    ("m-d-Y H:i", "Month-Day-Year Hour:Minute (08-15-2000 12:30)"),
                    ("Y-m-d H:i", "Year-Month-Day Hour:Minute (2000-08-15 12:30)"),
                ],
                default="d-m-Y H:i",
                help_text="The datetime format to be used in the application",
                max_length=20,
            ),
        ),
    ]
