{% extends "anonymous_base.html" %}
{% load crispy_forms_tags %}

{% block main %}

<div class="container">

<div
    class="row justify-content-center align-items-center g-2"
>
    
    <div class="col-6">
        <div class="card text-start">
            <div class="card-body">
                <h4 class="card-title">Password reset sent</h4>
                <p class="card-text">We’ve emailed you instructions for setting your password, if an account exists with the email you entered. You should receive them shortly.
                </p>
                <p>If you don’t receive an email, please make sure you’ve entered the address you registered with, and check your spam folder.</p>

                

            </div>
        </div>
        

    </div>
    
</div>


    
    
</div>



{% endblock main %}
