# Generated by Django 5.1.1 on 2024-09-16 22:38

import bloomerp.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "bloomerp",
            "0009_documenttemplatefreevariable_documenttemplateheader_and_more",
        ),
    ]

    operations = [
        migrations.RemoveField(
            model_name="file",
            name="created_at",
        ),
        migrations.RemoveField(
            model_name="file",
            name="updated_at",
        ),
        migrations.AlterField(
            model_name="file",
            name="file",
            field=models.FileField(upload_to=bloomerp.models.File.upload_to),
        ),
    ]
