# Generated by Django 5.1.1 on 2024-12-22 17:54

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "test_app",
            "0024_accommodation_avatar_customer_avatar_employee_avatar_and_more",
        ),
    ]

    operations = [
        migrations.AddField(
            model_name="employee",
            name="accommodations",
            field=models.ManyToManyField(
                related_name="employees",
                through="test_app.EmployeeOnAccommodation",
                to="test_app.accommodation",
            ),
        ),
    ]
