# Generated by Django 5.1.1 on 2025-01-08 01:08

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0065_alter_todo_priority_alter_todo_required_by"),
    ]

    operations = [
        migrations.RenameField(
            model_name="todo",
            old_name="requested_for",
            new_name="assigned_to",
        ),
    ]
