# Generated by Django 5.1.1 on 2025-01-11 02:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0069_alter_aiconversation_conversation_history"),
    ]

    operations = [
        migrations.AlterField(
            model_name="comment",
            name="object_id",
            field=models.CharField(max_length=36),
        ),
        migrations.AlterField(
            model_name="file",
            name="object_id",
            field=models.CharField(blank=True, max_length=36, null=True),
        ),
        migrations.AlterField(
            model_name="todo",
            name="object_id",
            field=models.CharField(blank=True, max_length=36, null=True),
        ),
    ]
