# Generated by Django 5.1.1 on 2024-10-03 21:23

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0027_filefolder_created_by_filefolder_datetime_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="filefolder",
            name="files",
            field=models.ManyToManyField(
                blank=True, null=True, related_name="folders", to="bloomerp.file"
            ),
        ),
    ]
