# Generated by Django 5.1.1 on 2024-09-22 23:24

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0009_rename_created_at_accommodation_datetime_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="customer",
            options={"verbose_name": "customer", "verbose_name_plural": "customers"},
        ),
    ]
