# Generated by Django 5.1.1 on 2024-11-20 21:34

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0016_alter_employee_manager"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="accommodation",
            options={
                "permissions": (
                    ("bulk_delete", "Can delete multiple objects from at once"),
                    ("bulk_change", "Can update multiple objects from at once"),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="employee",
            options={
                "permissions": (
                    ("bulk_delete", "Can delete multiple objects from at once"),
                    ("bulk_change", "Can update multiple objects from at once"),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="employeeonaccommodation",
            options={
                "permissions": (
                    ("bulk_delete", "Can delete multiple objects from at once"),
                    ("bulk_change", "Can update multiple objects from at once"),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="equipment",
            options={
                "permissions": (
                    ("bulk_delete", "Can delete multiple objects from at once"),
                    ("bulk_change", "Can update multiple objects from at once"),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="function",
            options={
                "permissions": (
                    ("bulk_delete", "Can delete multiple objects from at once"),
                    ("bulk_change", "Can update multiple objects from at once"),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="order",
            options={
                "permissions": (
                    ("bulk_delete", "Can delete multiple objects from at once"),
                    ("bulk_change", "Can update multiple objects from at once"),
                )
            },
        ),
        migrations.AlterModelOptions(
            name="product",
            options={
                "permissions": (
                    ("bulk_delete", "Can delete multiple objects from at once"),
                    ("bulk_change", "Can update multiple objects from at once"),
                )
            },
        ),
    ]
