# Generated by Django 5.1.1 on 2024-11-11 11:22

import bloomerp.models.auth
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0044_workspace"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="userdashboardview",
            name="created_by",
        ),
        migrations.RemoveField(
            model_name="userdashboardview",
            name="updated_by",
        ),
        migrations.RemoveField(
            model_name="userdashboardview",
            name="user",
        ),
        migrations.RemoveField(
            model_name="userdashboardview",
            name="widgets",
        ),
        migrations.AlterUniqueTogether(
            name="userkpidashboardviewpreference",
            unique_together=None,
        ),
        migrations.RemoveField(
            model_name="userkpidashboardviewpreference",
            name="created_by",
        ),
        migrations.RemoveField(
            model_name="userkpidashboardviewpreference",
            name="updated_by",
        ),
        migrations.RemoveField(
            model_name="userkpidashboardviewpreference",
            name="user",
        ),
        migrations.RemoveField(
            model_name="userkpidashboardviewpreference",
            name="widget",
        ),
        migrations.AlterField(
            model_name="workspace",
            name="content",
            field=models.JSONField(
                default=bloomerp.models.auth.get_default_workspace,
                help_text="The content of the workspace",
            ),
        ),
        migrations.DeleteModel(
            name="UserAppDashboard",
        ),
        migrations.DeleteModel(
            name="UserDashboardView",
        ),
        migrations.DeleteModel(
            name="UserKpiDashboardViewPreference",
        ),
    ]
