{% if field.help_text %}
    {% if help_text_inline %}
        <span id="{{ field.id_for_label }}_helptext" class="form-text">{{ field.help_text|safe}}</span>
    {% else %}
        <div {% if field.id_for_label %}id="{{ field.id_for_label }}_helptext" {% endif %}class="form-text">{{ field.help_text|safe }}</div>
    {% endif %}
{% endif %}
