# Generated by Django 5.1.1 on 2024-12-29 18:06

import bloomerp.models.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0026_remove_employee_accommodations"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="status",
            field=bloomerp.models.fields.StatusField(
                choices=[
                    ("pending", "Pending"),
                    ("processing", "Processing"),
                    ("completed", "Completed"),
                    ("cancelled", "Cancelled"),
                ],
                colored_choices=[
                    ("pending", "Pending", "#ffcc00"),
                    ("processing", "Processing", "#007bff"),
                    ("completed", "Completed", "#28a745"),
                    ("cancelled", "Cancelled", "#dc3545"),
                ],
                max_length=30,
            ),
        ),
    ]
