# Generated by Django 5.1.1 on 2024-09-15 22:05

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0001_initial"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="customer",
            options={"verbose_name": "Customer", "verbose_name_plural": "Customers"},
        ),
        migrations.AlterModelOptions(
            name="order",
            options={
                "permissions": [
                    ("bulk_delete", "Can delete multiple objects at once"),
                    ("bulk_update", "Can update multiple objects at once"),
                ]
            },
        ),
        migrations.AlterModelOptions(
            name="product",
            options={
                "permissions": [
                    ("bulk_delete", "Can delete multiple objects at once"),
                    ("bulk_update", "Can update multiple objects at once"),
                ]
            },
        ),
    ]
