# Generated by Django 5.1.1 on 2024-10-06 18:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0033_userappdashboard"),
    ]

    operations = [
        migrations.AlterField(
            model_name="userappdashboard",
            name="layout",
            field=models.JSONField(
                default={}, help_text="The layout of the app dashboard"
            ),
            preserve_default=False,
        ),
    ]
