# Generated by Django 5.1.1 on 2024-11-11 23:43

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0046_workspace_content_type_workspace_user"),
    ]

    operations = [
        migrations.RenameField(
            model_name="comment",
            old_name="comment",
            new_name="content",
        ),
        migrations.RemoveField(
            model_name="comment",
            name="user",
        ),
    ]
