<div class="pagetitle">
    <h1>{{ title }}</h1>
    <nav>
      <ol class="breadcrumb">
			<li class="breadcrumb-item">
				<a 
					class="pointer" 
					hx-get="{% url 'bloomerp_home_view' %}" 
					hx-target="#main-content" 
					hx-swap="innerHTML" 
					hx-push-url="true">Home</a>
			</li>
			{% if model_name_plural %}
			<li class="breadcrumb-item">
				<a 
				class="pointer" 
				hx-get="{% url model_dashboard_url %}" 
				hx-target="#main-content" 
				hx-swap="innerHTML" 
				hx-push-url="true">{{ model_name_plural | title }}</a>
			</li>
			{% endif %}
			
			{% if object %}
			<li class="breadcrumb-item"><a class="pointer" hx-get="{{object.get_absolute_url}}" hx-target="#main-content" hx-swap="innerHTML" hx-push-url="true">{{ object }}</a></li>
			{% endif %}

			<li class="breadcrumb-item active">{{ title }}</li>
      </ol>
    </nav>
</div>