# Generated by Django 5.1.1 on 2025-01-04 13:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp_tests", "0002_alter_child_options_alter_parent_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="child",
            options={},
        ),
        migrations.AlterModelOptions(
            name="many",
            options={},
        ),
        migrations.AlterModelOptions(
            name="parent",
            options={},
        ),
        migrations.AlterField(
            model_name="many",
            name="age",
            field=models.IntegerField(default=52),
        ),
        migrations.AlterModelTable(
            name="child",
            table="bloomerp_tests_child",
        ),
        migrations.AlterModelTable(
            name="many",
            table="bloomerp_tests_many",
        ),
        migrations.AlterModelTable(
            name="parent",
            table="bloomerp_tests_parent",
        ),
    ]
