{% include "snippets/list_view_filter.html" %}


<div 
    id="{{ datatable_id}}"
    hx-get="{% url 'components_datatable' %}?data_table_content_type_id={{ content_type_id }}&data_table_include_actions={{ include_actions }}&{{ initial_query }}"
    hx-target="#{{ datatable_id }}"
    hx-swap="innerHTML"
    hx-trigger="load"
    >
    
</div>