# Generated by Django 5.1.1 on 2024-10-02 22:48

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0024_folder"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="Folder",
            new_name="FileFolder",
        ),
        migrations.AlterModelOptions(
            name="filefolder",
            options={"managed": True},
        ),
        migrations.AlterModelTable(
            name="filefolder",
            table="bloomerp_file_folder",
        ),
    ]
