<!--Action-->
<div class="col mb-2">
        <select
            class="form-select form-select-sm"
            hx-get="{% url 'components_list_view_filter_inputs' %}?application_field_id={{ application_field.pk }}&step=input"
            hx-target="#filterValueInput{{id}}"
            hx-swap="innerHTML"
            hx-trigger="change"
            name="action"
        >   
                <option disabled selected>Choose an action</option>
            {% if application_field.field_type in 'CharField,TextField,StatusField' %}
                <option value="exact">Equals</option>
                <option value="icontains">Contains</option>
                <option value="startswith">Starts with</option>
                <option value="endswith">Ends with</option>
                <option value="isnull">Has value</option>
            {% elif application_field.field_type in 'ForeignKey,ManyToManyField' %}
                <option value="exact">Equals</option>
                <option value="advanced">Advanced</option>
            {% elif application_field.field_type in 'DateField,DateTimeField' %}
                <option value="exact">Equals</option>
                <option value="lte">Before</option>
                <option value="gte">After</option>
                <option value="day">Day</option>
                <option value="week">Week</option>
                <option value="month">Month</option>
                <option value="year">Year</option>
            {% elif application_field.field_type == 'BooleanField' %} 
                <option value="exact">Equals</option>
            {% elif application_field.field_type in 'DecimalField,BigAutoField,IntegerField,PositiveSmallIntegerField,PositiveIntegerField,AutoField,FloatField' %}
                <option value="equals">Equals</option>
                <option value="gte">Greater than</option>
                <option value="lte">Less than</option>
            {% endif %}
        </select>
</div>
<!--End Action-->

<!--Value-->
<div class="col" id="filterValueInput{{id}}">
    
</div>
<!--End Value-->
