{% load crispy_forms_tags %}
{% load crispy_forms_field %}
{% load bloomerp %}
{% load static %}

{% breadcrumb title='Query builder' model=model %}

<div class="card text-start">
    <div class="card-body">
        {% include "widget_views/snippets/sql_query_builder_snippet.html" %}
    </div>
</div>



