# Generated by Django 5.1.1 on 2025-01-04 12:46

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0060_documenttemplate_save_to_folder"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="documenttemplate",
            name="avatar",
        ),
        migrations.RemoveField(
            model_name="documenttemplatefreevariable",
            name="avatar",
        ),
        migrations.RemoveField(
            model_name="documenttemplateheader",
            name="avatar",
        ),
        migrations.RemoveField(
            model_name="documenttemplatestyling",
            name="avatar",
        ),
        migrations.RemoveField(
            model_name="sqlqueryfilter",
            name="filter_type",
        ),
        migrations.RemoveField(
            model_name="sqlqueryfilter",
            name="query",
        ),
        migrations.AddField(
            model_name="sqlqueryfilter",
            name="column",
            field=models.CharField(
                default="employee_id",
                help_text="Column name to filter on",
                max_length=255,
            ),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name="sqlqueryfilter",
            name="data_type",
            field=models.CharField(
                choices=[
                    ("STRING", "String"),
                    ("INTEGER", "Integer"),
                    ("FLOAT", "Float"),
                    ("DATE", "Date"),
                    ("DATETIME", "Datetime"),
                    ("BOOLEAN", "Boolean"),
                ],
                default="STRING",
                help_text="Data type of the filter",
                max_length=255,
            ),
        ),
        migrations.AddField(
            model_name="sqlqueryfilter",
            name="filter_operation",
            field=models.CharField(
                choices=[
                    ("=", "Equal"),
                    (">", "Greater"),
                    ("<", "Less"),
                    (">=", "Greater Or Equal"),
                    ("<=", "Less Or Equal"),
                    ("!=", "Not Equal"),
                    ("LIKE", "Like"),
                    ("NOT LIKE", "Not Like"),
                    ("IN", "In"),
                    ("NOT IN", "Not In"),
                    ("IS", "Is"),
                    ("IS NOT", "Is Not"),
                    ("BETWEEN", "Between"),
                    ("NOT BETWEEN", "Not Between"),
                    ("REGEXP", "Regexp"),
                    ("NOT REGEXP", "Not Regexp"),
                    ("EXISTS", "Exists"),
                    ("NOT EXISTS", "Not Exists"),
                ],
                default="=",
                help_text="Type of the filter",
                max_length=255,
            ),
        ),
        migrations.AlterField(
            model_name="sqlqueryfilter",
            name="name",
            field=models.CharField(help_text="Name of the filter", max_length=255),
        ),
    ]
