{% load static %}
<a 
    class="pointer"  
    data-bs-toggle="dropdown" 
    aria-expanded="false"
    hx-post="{% url 'components_bookmark' %}?object_id={{object_id}}&content_type_id={{content_type_id}}"
    hx-swap="innerHTML"
    hx-target="#{{ target }}"
    hx-trigger="click"
    href="#"
    >
    {% if bookmarked %}
        <img src="{% static 'bloomerp/icons/bookmark-filled.svg' %}" height="{{size}}" width="{{size}}" alt="menu" />
    {% else %}
        <img src="{% static 'bloomerp/icons/bookmark.svg' %}" height="{{size}}" width="{{size}}" alt="menu" />
    {% endif %}
</a>



