{% if avatar %}
    <img src="{{ avatar.url }}" class="{{ class_name }}" style="height:{{ size }}; width:{{ size }}" alt="avatar">
{% else %}
    <div class="initials {{ class_name }}" style="height:{{ size }}; width:{{ size }}">
        <span>{{ initials }}</span>
    </div>
{% endif %}


