<!-- filepath: /c:/Users/bloom/workspace/Bloomerp/bloomerp/templates/detail_views/bloomerp_detail_comments_view.html -->
{% load static %}

<h3 class="card-title">Comments</h3>

<div class="commentsContainer">
    <div
        hx-get="{% url 'components_comments' %}?content_type_id={{ content_type_id }}&object_id={{ object.pk }}"
        hx-trigger="load"
        hx-target="this"
        hx-swap="innerHTML"
        id="commentsContent"
    >
        
    </div>

    {% include 'detail_views/snippets/post_comment_snippet.html' with target="#commentsContent" object=object content_type_id=content_type_id%}

</div>
