# Generated by Django 5.1.1 on 2025-01-11 00:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0068_aiconversation"),
    ]

    operations = [
        migrations.AlterField(
            model_name="aiconversation",
            name="conversation_history",
            field=models.JSONField(blank=True, null=True),
        ),
    ]
