# Generated by Django 5.1.1 on 2024-09-26 23:43

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0012_equipment_employee_equipment"),
    ]

    operations = [
        migrations.AlterField(
            model_name="customer",
            name="name",
            field=models.CharField(
                help_text="The name of the customer", max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="employee",
            name="first_name",
            field=models.CharField(
                help_text="The first name of the employee", max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="employee",
            name="last_name",
            field=models.CharField(
                help_text="The last name of the employee", max_length=255
            ),
        ),
    ]
