# Generated by Django 5.1.1 on 2024-11-20 22:12

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("bloomerp", "0048_remove_userlistviewpreference_is_main"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="file",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="filefolder",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
        migrations.AlterModelOptions(
            name="widget",
            options={
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "bulk_change",
                    "bulk_delete",
                    "bulk_add",
                ),
                "managed": True,
            },
        ),
    ]
