# Generated by Django 5.1.1 on 2024-09-26 15:45

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0010_alter_customer_options"),
    ]

    operations = [
        migrations.CreateModel(
            name="Function",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("datetime_created", models.DateTimeField(auto_now_add=True)),
                ("datetime_updated", models.DateTimeField(auto_now=True)),
                ("name", models.CharField(max_length=255)),
                ("description", models.TextField(blank=True, null=True)),
            ],
            options={
                "permissions": (
                    (
                        "bulk_delete%(class)s",
                        "Can delete multiple objects from %(class)s at once",
                    ),
                    (
                        "bulk_change%(class)s",
                        "Can update multiple objects from %(class)s at once",
                    ),
                ),
                "abstract": False,
            },
        ),
        migrations.AddField(
            model_name="employee",
            name="manager",
            field=models.ForeignKey(
                blank=True,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="test_app.employee",
            ),
        ),
        migrations.AddField(
            model_name="employee",
            name="functions",
            field=models.ManyToManyField(to="test_app.function"),
        ),
    ]
