{% load static %}

<meta charset="utf-8" />
<meta
  content="width=device-width, initial-scale=1.0"
  name="viewport"
/>

<title>
  Bloomerp {% block title %}{% endblock title %}
</title>
<meta
  content=""
  name="description"
/>
<meta
  content=""
  name="keywords"
/>

<!-- Favicons -->
<link
  href="{% static 'bloomerp/img/logo-touch-icon.png' %}"
  rel="icon"
/>
<link
  href="{% static 'bloomerp/img/logo-touch-icon.png' %}"
  rel="logo-touch-icon"
/>

<!-- Google Fonts -->
<link
  href="https://fonts.gstatic.com"
  rel="preconnect"
/>
<link
  href="https://fonts.googleapis.com/css?family=Open+Sans:300,300i,400,400i,600,600i,700,700i|Nunito:300,300i,400,400i,600,600i,700,700i|Poppins:300,300i,400,400i,500,500i,600,600i,700,700i"
  rel="stylesheet"
/>


<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
<link href="https://fonts.googleapis.com/css2?family=IBM+Plex+Sans:ital,wght@0,100;0,200;0,300;0,400;0,500;0,600;0,700;1,100;1,200;1,300;1,400;1,500;1,600;1,700&display=swap" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/quill@2.0.2/dist/quill.snow.css" rel="stylesheet" />

<!-- Vendor CSS Files -->
<link
  href="{% static 'bloomerp/vendor/bootstrap/css/bootstrap.min.css' %}"
  rel="stylesheet"
/>
<link
  href="{% static 'bloomerp/vendor/bootstrap-icons/bootstrap-icons.css' %}"
  rel="stylesheet"
/>
<link
  href="{% static 'bloomerp/vendor/boxicons/css/boxicons.min.css' %}"
  rel="stylesheet"
/>
<link
  href="{% static 'bloomerp/vendor/quill/quill.snow.css' %}"
  rel="stylesheet"
/>
<link
  href="{% static 'bloomerp/vendor/quill/quill.bubble.css'%}"
  rel="stylesheet"
/>
<link
  href="{% static 'bloomerp/vendor/remixicon/remixicon.css' %}"
  rel="stylesheet"
/>
<link
  href="{% static 'bloomerp/vendor/simple-datatables/style.css' %}"
  rel="stylesheet"
/>
<link
  rel="stylesheet"
  href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.3/font/bootstrap-icons.css"
/>

<!--HTMX-->
<script
  src="https://unpkg.com/htmx.org@1.9.7"
  integrity="sha384-EAzY246d6BpbWR7sQ8+WEm40J8c3dHFsqC58IgPlh4kMbRRI6P6WA+LA/qGAyAu8"
  crossorigin="anonymous"
></script>

<!--HTMX Download-->
<script src="{% static 'bloomerp/js/htmx-download.js' %}"></script>

<!-- Template Main CSS File -->
<link
  href="{% static 'bloomerp/css/style.css' %}"
  rel="stylesheet"
/>

<!-- Datatable-->
<script src="{% static 'bloomerp/js/datatable.js' %}"></script>
<!-- Datatable-->

<!-- Own stylesheets-->
<link
href="{% static 'css/images.css' %}"
  rel="stylesheet"
/>

<script
  src="https://cdn.tiny.cloud/1/l1pz8u8aljl0fdzkb4xxqtbnclu0po0sqsapa6yijzuideur/tinymce/6/tinymce.min.js"
  referrerpolicy="origin"
></script>

<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.9.0/ace.js" integrity="sha512-jZW/Y5ZrHGo7MsZjfcmajLQKN2ax6njLZ6tuiPkhGH3l2Y0FAsGXS6uWFf/ItiR6oGVeP4TXpGPXMGEqFl7WSA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>


<!--JQuery-->
<script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>

<!--Simple datatable-->
<script
  src="https://cdn.jsdelivr.net/npm/simple-datatables@latest"
  type="text/javascript"
></script>

<!--Quil editor-->
<script src="https://cdn.jsdelivr.net/npm/quill@2.0.2/dist/quill.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.4.12/ace.js"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.2/mode-html.min.js" integrity="sha512-JSkDZ0Crk8+F/F/lCqh6LZ/mzPqhSrRanUC3TExEziPsbLPFIJQmR5R7p954sdM88cOL9+WlVR6XBFJa3nXcdA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.3/ext-beautify.min.js" integrity="sha512-uXfi0GwpQZcHIhGOMMHeNYtBSjt7qDXjXHmjShWSp+RWMSmjdy69N7M/pufinvQLv6rSYlpbSXqSnLRzWE952w==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>

<!--Text editors-->
<script src="{% static 'bloomerp/vendor/quill/image-drop.min.js' %}"></script>

<script src="{% static 'bloomerp/vendor/quill/image-resize.min.js' %}"></script>

<script src="{% static 'bloomerp/vendor/tinymce/tinymce.min.js' %}"></script>

<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.2/mode-sql.min.js" integrity="sha512-dABa+YCy/MOELLU5BKnJeR/pcORL8icJNR1TBZWrRmlFoWXZEFketX6Qx/DVBkewMZC8mUOGJMJ70fwxcpIDCw==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.2/mode-json.min.js" integrity="sha512-K+H+3WTfhwE9fnfv4makUYJxz4kwIadQPOjGHAmOT96FtMSPRnvnuGR/sZjuNB2MmmHQ94Mnc9zoDxTHKMMEww==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.2/mode-python.min.js" integrity="sha512-DUdq0nHbbCHQMqQNALNivk5tAdpFWOpm3mplXDwBqIpXD6/vfgXp8fESbfsnePQT3jZKVI3mCbEQumz/S4IHPA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.2/mode-html.min.js" integrity="sha512-JSkDZ0Crk8+F/F/lCqh6LZ/mzPqhSrRanUC3TExEziPsbLPFIJQmR5R7p954sdM88cOL9+WlVR6XBFJa3nXcdA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.2/mode-css.min.js" integrity="sha512-/j2txHwfn9J3633V80jkkMDKbz0nq3hxhnrh2dZIKKQzFYuEVyMLx+wsbtgC2aViUYenhx1mb4EuZyGiluBwXA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="https://cdnjs.cloudflare.com/ajax/libs/ace/1.36.2/mode-javascript.min.js" integrity="sha512-S5TwCMItd+YdNiTApqHt2QkA2sd90dgpWxHoYhulWm+Nb/i9GppPsve8IOraaTj56uNJgIOtmFQFggL1PuKkWA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>

<!--Zero MD-->
<script type="module" src="https://cdn.jsdelivr.net/npm/zero-md@3?register"></script>


<!--Full calendar-->
<script src='https://cdn.jsdelivr.net/npm/fullcalendar@6.1.15/index.global.min.js'></script>
