# Generated by Django 5.1.1 on 2024-10-28 17:17

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0015_employee_date_of_birth"),
    ]

    operations = [
        migrations.AlterField(
            model_name="employee",
            name="manager",
            field=models.ForeignKey(
                blank=True,
                help_text="The manager of the employee",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="direct_reports",
                to="test_app.employee",
            ),
        ),
    ]
