# Generated by Django 5.1.1 on 2024-09-17 21:28

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("test_app", "0008_accommodation_employee_employeeonaccommodation"),
    ]

    operations = [
        migrations.RenameField(
            model_name="accommodation",
            old_name="created_at",
            new_name="datetime_created",
        ),
        migrations.RenameField(
            model_name="accommodation",
            old_name="updated_at",
            new_name="datetime_updated",
        ),
        migrations.RenameField(
            model_name="customer",
            old_name="created_at",
            new_name="datetime_created",
        ),
        migrations.RenameField(
            model_name="customer",
            old_name="updated_at",
            new_name="datetime_updated",
        ),
        migrations.RenameField(
            model_name="employee",
            old_name="created_at",
            new_name="datetime_created",
        ),
        migrations.RenameField(
            model_name="employee",
            old_name="updated_at",
            new_name="datetime_updated",
        ),
        migrations.RenameField(
            model_name="employeeonaccommodation",
            old_name="created_at",
            new_name="datetime_created",
        ),
        migrations.RenameField(
            model_name="employeeonaccommodation",
            old_name="updated_at",
            new_name="datetime_updated",
        ),
        migrations.RenameField(
            model_name="order",
            old_name="created_at",
            new_name="datetime_created",
        ),
        migrations.RenameField(
            model_name="order",
            old_name="updated_at",
            new_name="datetime_updated",
        ),
        migrations.RenameField(
            model_name="product",
            old_name="created_at",
            new_name="datetime_created",
        ),
        migrations.RenameField(
            model_name="product",
            old_name="updated_at",
            new_name="datetime_updated",
        ),
    ]
